@@ -2,10 +2,10 @@ name = "maloja"
 desc = "Self-hosted music scrobble database"
 author = {
 	"name":"Johannes Krattenmacher",
-	"email":"maloja@krateng.dev",
+	"email":"maloja@dev.krateng.ch",
 	"github": "krateng"
 }
-version = 2,12,5
+version = 2,12,6
 versionstr = ".".join(str(n) for n in version)
 links = {
 	"pypi":"malojaserver",
